@@ -28,7 +28,7 @@ class ReverseProxyConnection(object):
         self.log("Connection closed")
         self.front_conn.set_close_cb(None)
         self.back_conn.set_close_cb(None)
-        conn.close()
+        conn.soft_close()
         self.front_conn = None
         self.back_conn = None
 
